@@ -1,6 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML;
 our $AUTHORITY = 'cpan:JANDREW';
-use version 0.77; our $VERSION = qv('v0.38.8');
+use version 0.77; our $VERSION = qv('v0.38.10');
 ###LogSD	warn "You uncovered internal logging statements for Spreadsheet::XLSX::Reader::LibXML-$VERSION";
 
 use 5.010;
@@ -108,6 +108,14 @@ my	$flag_settings ={
 			cache_positions   => 1,
 			from_the_edge     => 0,
 		},
+		like_ParseExcel =>{
+			count_from_zero   => 0,
+			values_only       => 1,
+			empty_is_end      => 1,
+			group_return_type => 'value',
+			cache_positions   => 1,
+			from_the_edge     => 0,
+		},
 	};
 
 #########1 Public Attributes  3#########4#########5#########6#########7#########8#########9
@@ -216,7 +224,7 @@ has format_string_parser =>(
 	);
 
 has group_return_type =>(
-		isa		=> Enum[qw( unformatted value instance )],
+		isa		=> Enum[qw( unformatted value instance xml_value )],
 		reader	=> 'get_group_return_type',
 		writer	=> 'set_group_return_type',
 	);
@@ -981,7 +989,7 @@ Spreadsheet::XLSX::Reader::LibXML - Read xlsx spreadsheet files with LibXML
 </a>
 
 <a>
-	<img src="https://img.shields.io/badge/this version-0.38.8-brightgreen.svg" alt="this version">
+	<img src="https://img.shields.io/badge/this version-0.38.10-brightgreen.svg" alt="this version">
 </a>
 
 <a href="https://metacpan.org/pod/Spreadsheet::XLSX::Reader::LibXML">
@@ -1646,17 +1654,19 @@ L<Spreadsheet::XLSX::Reader::LibXML::ParseExcelFormatStrings//get_date_behavior>
 B<Definition:> Traditionally ParseExcel returns a cell object with lots of methods 
 to reveal information about the cell.  In reality the extra information is not used very 
 much (witness the popularity of L<Spreadsheet::XLSX>).  Because many users don't need or 
-want the extra cell formatting information it is possible to get either the raw cell value 
-or the formatted cell value returned either the way the Excel file specified or the way you 
-specify instead of a Cell instance with all the data. .  See 
+want the extra cell formatting information it is possible to get either the raw xml value, 
+the raw visible cell value (seen in the Excel format bar), or the formatted cell value 
+returned either the way the Excel file specified or the way you specify instead of a Cell 
+instance with all the data. .  See 
 L<Spreadsheet::XLSX::Reader::LibXML::Worksheet/custom_formats> to insert custom targeted 
 formats for use with the parser.  All empty cells return undef no matter what.
 
 B<Default> instance
 
 B<Range> instance = returns a populated L<Spreadsheet::XLSX::Reader::LibXML::Cell> instance,
-unformatted = returns just the raw value of the cell with no modifications, value = returns 
-just the formatted value stored in the excel cell
+unformatted = returns just the raw visible value of the cell shown in the Excel formula bar, 
+value = returns just the formatted value stored in the excel cell, xml_value = the raw value 
+for the cell as stored in the sub-xml files
 
 B<attribute methods> Methods provided to adjust this attribute
 		
