@@ -1,6 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::Cell;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = qv('v0.38.8');
+use version; our $VERSION = qv('v0.38.10');
 ###LogSD	warn "You uncovered internal logging statements for Spreadsheet::XLSX::Reader::LibXML::Cell-$VERSION";
 
 $| = 1;
@@ -176,7 +176,8 @@ sub value{
 	###LogSD		$phone->talk( level => 'debug', message => [
 	###LogSD			'Reached the -value- function' ] );
 	###LogSD		$phone->talk( level => 'trace', message => [ "Cell:", $self ] );
-	my	$unformatted = $self->unformatted;
+	my	$unformatted = $self->has_xml_value ? $self->xml_value : undef;
+	#~ my	$unformatted = $self->unformatted;
 	return	$self->_return_value_only(
 				$unformatted, 
 				$self->get_coercion,
@@ -273,7 +274,7 @@ sub DEMOLISH{
 	###LogSD	my	$phone = Log::Shiras::Telephone->new(
 	###LogSD					name_space 	=> $self->get_log_space .  '::Cell::DEMOLISH', );
 	###LogSD		$phone->talk( level => 'debug', message => [
-	###LogSD			"clearing the cell for cell ID:" . $self->cell_id, ] );
+	###LogSD			"clearing the cell for cell-ID:" . $self->cell_id, ] );
 	#~ print "Clearing coercion\n";
 	$self->clear_coercion;
 	#~ print "Clearing error instance\n";
