@@ -1,6 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::XMLReader::Styles;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = qv('v0.38.8');
+use version; our $VERSION = qv('v0.38.10');
 ###LogSD	warn "You uncovered internal logging statements for Spreadsheet::XLSX::Reader::LibXML::XMLReader::Styles-$VERSION";
 
 use 5.010;
@@ -82,7 +82,11 @@ sub get_format_position{
 		###LogSD		"Already collected this general format at position: $position"  ] );
 		$already_got_it = 1;
 	}
-	return $self->_get_sub_position_ref if $already_got_it;
+	if( $already_got_it ){
+		my $ref = $self->_get_sub_position_ref;
+		delete $ref->{$exclude_header} if $exclude_header;
+		return $ref;
+	}
 	
 	# build from scratch	
 	my	$result = $self->_get_header_and_position( 'cellXfs', $position );
